@@ -1,14 +1,6 @@
-/* $Id: Grab.c,v 1.3 1997/11/13 22:41:04 gjb Exp $ */
-/* This module is based on code distributed with fvwm with no
- * copyright notice. Thus, the code it is based on should be in
- * the public domain.
- *
- * It may be used or distributed under either the FVWM license 
- * (see COPYING.fvwm) or the GNU General Public License (see COPYING.GPL and
- * the description below)
- * Copyright 1997, Maciej Stachowiak and Greg J Badros
- ****************************************************************************/
-/*      Copyright (C) 1997, Maciej Stachowiak
+/* $Id: Grab.c,v 1.7 1998/07/18 21:35:09 gjb Exp $ */
+/*
+ *      Copyright (C) 1997, Maciej Stachowiak and Greg J. Badros
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,14 +17,16 @@
  * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307 USA
  *
- * As a special exception, this file may alternatively be distributed under 
- * the fvwm license (see COPYING.FVWM).
- *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <X11/Xlib.h>
 
+
 static int xgrabcount = 0;
 
 void 
