@@ -1,12 +1,10 @@
+/* $Id: complex.c,v 1.13 1998/07/18 21:35:15 gjb Exp $
+ * complex.c
+ */
 
-/****************************************************************************
- * This module is all new
- * by Rob Nation 
- * Copyright 1993 Robert Nation. No restrictions are placed on this code,
- * as long as the copyright notice is preserved
- ****************************************************************************/
-
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <stdio.h>
 #include <signal.h>
@@ -15,24 +13,25 @@
 #include <unistd.h>
 
 #include "scwm.h"
-#include "menus.h"
-#include "misc.h"
 #include "screen.h"
+#include "xmisc.h"
+#include "syscompat.h"
+#include "focus.h"
 
-/*****************************************************************************
- *
+/*
+ * IsClick(...)
  * Waits Scr.ClickTime, or until it is evident that the user is not
  * clicking, but is moving the cursor
- *
- ****************************************************************************/
+ * This function is derived from code by Robert Nation
+ */
+
 /* FIXGJB: a single, slow click with no movement should
-   still cound as a single click */
+   still count as a single click */
 Bool 
 IsClick(int x, int y, unsigned EndMask, XEvent * d)
 {
   int xcurrent, ycurrent, total = 0;
   Time t0;
-  extern Time lastTimestamp;
 
   xcurrent = x;
   ycurrent = y;
@@ -42,7 +41,7 @@ IsClick(int x, int y, unsigned EndMask, XEvent * d)
 	 (x - xcurrent < 3) && (x - xcurrent > -3) &&
 	 (y - ycurrent < 3) && (y - ycurrent > -3) &&
 	 ((lastTimestamp - t0) < Scr.ClickTime)) {
-    sleep_ms(20);
+    usleep(20);
     total += 20;
     if (XCheckMaskEvent(dpy, EndMask, d)) {
       StashEventTime(d);
