@@ -1,8 +1,20 @@
-/* $Id: decor.h,v 1.6 1997/11/13 22:41:07 gjb Exp $ */
+/* $Id: decor.h,v 1.11 1998/07/27 01:07:57 gjb Exp $
+ * decor.h
+ * (C) 1997, 1998 Maciej Stachowiak and Greg J. Badros
+ */
+
 
 #ifndef DECOR_H
 #define DECOR_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <libguile.h>
+#include "scwm.h"
+#include "screen.h"
+
 #undef EXTERN
 #undef EXTERN_SET
 #ifdef DECOR_IMPLEMENTATION
@@ -13,9 +25,6 @@
 #define EXTERN_SET(x,y) extern x
 #endif
 
-#include <libguile.h>
-#include "scwm.h"
-#include "screen.h"
 
 typedef struct {
   ScwmDecor *sd;
@@ -27,7 +36,7 @@ EXTERN_SET(ScwmDecor *cur_decor,NULL);
 
 EXTERN long scm_tc16_scwm_decor;
 
-#define DECORP(X) (SCM_CAR(X) == (SCM)scm_tc16_scwm_decor)
+#define DECORP(X) (SCM_NIMP(X) && SCM_CAR(X) == (SCM)scm_tc16_scwm_decor)
 #define DECOR(X)  ((scwm_decor *)SCM_CDR(X))
 #define SCWMDECOR(X) (((scwm_decor *)SCM_CDR(X))->sd)
 
@@ -37,20 +46,10 @@ EXTERN long scm_tc16_scwm_decor;
    setting the default decor. Other than that, the mark/sweep
    algorithm should be sufficient. */
 
-#define DECORREF(X) {if (!DECOR(X)->refcnt++) {scm_protect_object(X);}}
-#define DECORUNREF(X) {if (DECOR(X)->refcnt--) {scm_unprotect_object(X);}}
-
-
-size_t free_decor(SCM obj);
-int print_decor(SCM obj, SCM port, scm_print_state * pstate);
-SCM mark_decor(SCM obj);
+#define DECORREF(X) do {if (DECOR(X)->refcnt == 0) {DECOR(X)->refcnt++; scm_protect_object(X);}} while (0)
+#define DECORUNREF(X) do {int x = --DECOR(X)->refcnt; if (x == 0) scm_unprotect_object(X); else if (x < 0) DECOR(X)->refcnt = 0; } while (0)
 
 SCM decor2scm(ScwmDecor * fl);
-SCM make_decor(SCM name);
-SCM default_decor();
-SCM set_current_decor_x(SCM decor);
-SCM current_decor();
-SCM set_window_decor_x(SCM decor, SCM win);
 
 #endif /* DECOR_H */
 
