@@ -1,6 +1,15 @@
+/* $Id: mwmcom.h,v 1.3 1998/07/18 21:35:26 gjb Exp $
+ * mwmcom.h
+ * (C) 1997, 1998 Maciej Stachowiak and Greg J. Badros
+ */
+
 #ifndef MWMCOM_H
 #define MWMCOM_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 /***************************************************************************
  * Please translate the strings into the language which you use for 
  * your pop-up menus.
