@@ -1,9 +1,15 @@
-/* $Id: util.h,v 1.6 1997/11/13 22:41:12 gjb Exp $
+/* $Id: util.h,v 1.7 1998/07/18 21:35:32 gjb Exp $
  * util.h
+ * (C) 1997, 1998 Maciej Stachowiak and Greg J. Badros
  */
+
 #ifndef UTIL_H
 #define UTIL_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 void redraw_titlebars(ScwmDecor * fl, int extra_height);
 void redraw_borders(ScwmDecor *fl) ;
 void refresh_common(Window win_or_root);
